# TextMarkupDocument


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**type** | **str** |  | 

## Example

```python
from src.client.generated.models.text_markup_document import TextMarkupDocument

# TODO update the JSON string below
json = "{}"
# create an instance of TextMarkupDocument from a JSON string
text_markup_document_instance = TextMarkupDocument.from_json(json)
# print the JSON string representation of the object
print(TextMarkupDocument.to_json())

# convert the object into a dict
text_markup_document_dict = text_markup_document_instance.to_dict()
# create an instance of TextMarkupDocument from a dict
text_markup_document_from_dict = TextMarkupDocument.from_dict(text_markup_document_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


